@@ -6,7 +6,7 @@
 #
 # Setup
 #
-# VERSION: $Id: common.pm,v 2.01 2011/10/10 16:38:57 stefanb2 Exp $
+# VERSION: $Id: common.pm,v 2.02 2014/06/14 18:18:36 stefanb2 Exp $
 #
 # INSERT FROM HERE ############################################################
 package fi::common;
@@ -94,10 +94,11 @@ sub fetchRaw($;$$) {
 }
 
 # Fetch URL as parsed HTML::TreeBuilder
-sub fetchTree($;$$) {
-  my($url, $encoding, $nofail) = @_;
+sub fetchTree($;$$$) {
+  my($url, $encoding, $nofail, $unknown) = @_;
   my $content = fetchRaw($url, $encoding, $nofail);
   my $tree = HTML::TreeBuilder->new();
+  $tree->ignore_unknown(!$unknown);
   local $SIG{__WARN__} = sub { carp("fetchTree(): $_[0]") };
   $tree->parse($content) or croak("fetchTree() parse failure for '$url'");
   $tree->eof;
