@@ -6,7 +6,7 @@
 #
 # Setup
 #
-# VERSION: $Id: programme.pm,v 2.01 2012/02/11 20:31:39 stefanb2 Exp $
+# VERSION: $Id: programme.pm,v 2.04 2014/06/15 17:27:26 stefanb2 Exp $
 #
 # INSERT FROM HERE ############################################################
 package fi::programme;
@@ -28,9 +28,9 @@ sub _trim {
 sub new {
   my($class, $channel, $language, $title, $start, $stop) = @_;
   _trim($title);
-  croak "${class}::new called without valid title, start or stop"
+  croak "${class}::new called without valid title or start"
     unless defined($channel) && defined($title) && (length($title) > 0) &&
-           defined($start) && defined($stop);
+           defined($start);
 
   my $self = {
 	      channel  => $channel,
@@ -64,8 +64,40 @@ sub episode {
     push(@{ $self->{episode} }, [$episode, $language]);
   }
 }
+sub season_episode {
+  my($self, $season, $episode) = @_;
+  # only accept a pair of valid, positive integers
+  if (defined($season) && defined($episode)) {
+    $season  = int($season);
+    $episode = int($episode);
+    if (($season  > 0) && ($episode > 0)) {
+      $self->{season}         = $season;
+      $self->{episode_number} = $episode;
+    }
+  }
+}
+sub start {
+  my($self, $start) = @_;
+  $self->{start} = $start
+    if defined($start) && length($start);
+  $start = $self->{start};
+  croak "${self}::start: object without valid start time"
+    unless defined($start);
+  return($start);
+}
+sub stop {
+  my($self, $stop) = @_;
+  $self->{stop} = $stop
+    if defined($stop) && length($stop);
+  $stop = $self->{stop};
+  croak "${self}::stop: object without valid stop time"
+    unless defined($stop);
+  return($stop);
+}
 
+# read-only
 sub language { $_[0]->{language} }
+sub title    { $_[0]->{title}    }
 
 # Convert seconds since Epoch to XMLTV time stamp
 #
@@ -78,12 +110,12 @@ sub _epoch_to_xmltv_time($) {
 
   # Unfortunately strftime()'s %z is not portable...
   #
-  # return(strftime("%Y%m%d%H%M00 %z", localtime($time));
+  # return(strftime("%Y%m%d%H%M%S %z", localtime($time));
   #
   # ...so we have to roll our own:
   #
   my @time = localtime($time); #               is_dst
-  return(strftime("%Y%m%d%H%M00 +0", @time) . ($time[8] ? "3": "2") . "00");
+  return(strftime("%Y%m%d%H%M%S +0", @time) . ($time[8] ? "3": "2") . "00");
 }
 
 # Configuration data
@@ -98,6 +130,8 @@ sub dump {
   my $title       = $self->{title};
   my $category    = $self->{category};
   my $description = $self->{description};
+  my $episode     = $self->{episode_number};
+  my $season      = $self->{season};
   my $subtitle    = $self->{episode};
 
   #
@@ -119,7 +153,7 @@ sub dump {
   #
   # Check 1: object already contains episode
   #
-  my($left, $right);
+  my($left, $special, $right);
   if (defined($subtitle)) {
     # nothing to be done
   }
@@ -157,20 +191,43 @@ sub dump {
   #
   # Example:
   #
-  #   config:      series title Batman
+  #   config:      series description Batman
   #   description: Pingviinin paluu. Amerikkalainen animaatiosarja....
   #
   # This will generate a program with
   #
   #   title:       Batman
-  #   sub-title:   Pingviinin paluu.
+  #   sub-title:   Pingviinin paluu
+  #   description: Amerikkalainen animaatiosarja....
+  #
+  # Special cases
+  #
+  #   text:        Pingviinin paluu?. Amerikkalainen animaatiosarja....
+  #   sub-title:   Pingviinin paluu?
+  #   description: Amerikkalainen animaatiosarja....
+  #
+  #   text:        Pingviinin paluu... Amerikkalainen animaatiosarja....
+  #   sub-title:   Pingviinin paluu...
+  #   description: Amerikkalainen animaatiosarja....
+  #
+  #   text:        Pingviinin paluu?!? Amerikkalainen animaatiosarja....
+  #   sub-title:   Pingviinin paluu?!?
   #   description: Amerikkalainen animaatiosarja....
   #
   elsif ((defined $description)               &&
 	 (exists $series_description{$title}) &&
-         (($left, $right) = ($description =~ /^\s*([^.!?]+[.!?])\s*(.*)/))) {
-    # We only remove period from episode title, preserve others
-    $left =~ s/\.$//;
+         (($left, $special, $right) = ($description =~ /^\s*([^.!?]+[.!?])([.!?]+\s+)?\s*(.*)/))) {
+    unless (defined $special) {
+      # We only remove period from episode title, preserve others
+      $left =~ s/\.$//;
+    } elsif (($left    !~ /\.$/) &&
+	     ($special =~ /^\.\s/)) {
+      # Ignore extraneous period after sentence
+    } else {
+      # Preserve others, e.g. ellipsis
+      $special =~ s/\s+$//;
+      $left    .= $special;
+    }
     debug(3, "XMLTV series title '$title' episode '$left'");
     ($subtitle, $description) = ($left, $right);
   }
@@ -200,6 +257,10 @@ sub dump {
     $xmltv{desc} = [[$description, $language]];
     debug(4, "XMLTV programme description: $description");
   }
+  if (defined($season) && defined($episode)) {
+    $xmltv{'episode-num'} =  [[ ($season - 1) . '.' . ($episode - 1) . '.', 'xmltv_ns' ]];
+    debug(4, "XMLTV programme season/episode: $season/$episode");
+  }
 
   $writer->write_programme(\%xmltv);
 }
