@@ -1,5 +1,11 @@
 package XMLTV::Configure;
 
+# use version number for feature detection:
+# 0.005065 : can use 'constant' in write_string()
+# 0.005065 : comments in config file not restricted to starting in first column
+# 0.005066 : make writes to the config-file atomic
+our $VERSION = 0.005066;
+
 BEGIN {
     use Exporter   ();
     our (@ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
@@ -71,14 +77,14 @@ sub LoadConfig
     {
 	$line =~ tr/\n\r//d;
 	next if $line =~ /^\s*$/;
-	next if $line =~ /^#/;
+	next if $line =~ /^\s*#/;
         
 	# Only accept lines with key=value or key!value. 
 	# No white-space is allowed before
 	# the equal-sign. White-space after the equal-sign is considered
 	# part of the value, except for white-space at the end of the line
 	# which is ignored.
-	my( $key, $sign, $value ) = ($line=~ /^(\S+)([=!])(.*?)\s*$/ );
+	my( $key, $sign, $value ) = ($line=~ /^(\S+)([=!])(.*?)\s*(#.*)?$/ );
 
 	return undef unless defined $key;
 	if( $sign eq '=' )
@@ -110,8 +116,12 @@ sub SaveConfig
 {
     my( $conf, $config_file ) = @_;
     
-    open OUT, "> $config_file" 
-	or die "Failed to open $config_file for writing.";
+    # Test if configuration file is writeable
+    if (-f $config_file && !(-w $config_file)) { die "Cannot write to $config_file"; }
+ 
+    # Create temporary configuration file.
+    open OUT, "> $config_file.TMP" 
+	or die "Failed to open $config_file.TMP for writing.";
 
     foreach my $key (keys %{$conf})
     {
@@ -135,6 +145,9 @@ sub SaveConfig
     }
 
     close OUT;
+    
+    # Store temporary configuration file
+    rename "$config_file.TMP", $config_file or die "Failed to write to $config_file";  
 }
 
 =item Configure
@@ -167,24 +180,30 @@ sub Configure
     
     my $nextstage = 'start';
     
-    # Clear the configuration file.
-    open OUT, "> $conffile" or die "Failed to write to $conffile";
+    # Test if configuration file is writeable
+    if (-f $conffile && !(-w $conffile)) { die "Cannot write to $conffile"; }
+ 
+    # Create temporary configuration file.
+    open OUT, "> $conffile.TMP" or die "Failed to write to $conffile.TMP";
     close OUT;
     
     do
     {
-	my $stage = &$stagesub( $nextstage, LoadConfig( $conffile ) );
+	my $stage = &$stagesub( $nextstage, LoadConfig( "$conffile.TMP" ) );
 	$nextstage = configure_stage( $stage, $conffile, $lang );
     } while ($nextstage ne "select-channels" );
 
     # No more nextstage. Let the user select channels. Do not present
     # channel selection if the configuration is using lineups where
     # channels are determined automatically
-    my $conf = LoadConfig( $conffile );
+    my $conf = LoadConfig( "$conffile.TMP" );
     if (! exists $conf->{lineup}) {
         my $channels = &$listsub( $conf, $opt );
         select_channels( $channels, $conffile, $lang );
     }
+    
+    # Store temporary configuration file
+    rename "$conffile.TMP", $conffile or die "Failed to write to $conffile";
 }
 
 sub configure_stage
@@ -193,8 +212,8 @@ sub configure_stage
 
     my $nextstage = undef;
 
-    open OUT, ">> $conffile" 
-	or die "Failed to open $conffile for writing";
+    open OUT, ">> $conffile.TMP" 
+	or die "Failed to open $conffile.TMP for writing";
 
     my $xml = XML::LibXML->new;
     my $doc = $xml->parse_string($stage);
@@ -216,16 +235,18 @@ sub configure_stage
 	my $title = getvalue( $p, 'title', $lang );
 	my $description = getvalue( $p, 'description', $lang );
 	my $default = $p->findvalue( '@default' );
+	my $constant = $p->findvalue( '@constant' );
 	
 	my $value;
 
-	my $q = defined( $default ) ? "$title: [$default]" :
+	my $q = $default ne '' ? "$title: [$default]" :
 	                              "$title:";
 
-	say( "$description" );
+	say( "$description" ) if $constant eq '';
 	if( $tag eq 'string' )
 	{
-	    $value = ask( "$q" );
+	    $value = $constant if $constant ne '';
+	    $value = ask( "$q" ) if $constant eq '';
 	    $value = $default if $value eq "";
 	    print OUT "$id=$value\n";
 	}
@@ -288,8 +309,8 @@ sub select_channels
 {
     my( $channels,  $conffile, $lang ) = @_;
 
-    open OUT, ">> $conffile" 
-	or die "Failed to open $conffile for writing";
+    open OUT, ">> $conffile.TMP" 
+	or die "Failed to open $conffile.TMP for writing";
 
     my $xml = XML::LibXML->new;
     my $doc;
