@@ -1,4 +1,4 @@
-# $Id: Summarize.pm,v 1.3 2004/01/03 14:52:53 epaepa Exp $
+# $Id: Summarize.pm,v 1.4 2014/05/05 16:00:31 bilbo_uk Exp $
 package XMLTV::Summarize;
 use strict;
 use base 'Exporter';
@@ -133,6 +133,14 @@ sub summarize( $$ ) {
 				 \&shorter)->[0];
 	}
 	
+	my $desc;
+	if (defined $_->{'desc'}) {
+		# No comparator, just get the first one in the preferred language (this is probably the best/shortest in most cases)
+	    $desc
+	      = XMLTV::best_name(\@PREF_LANGS, $_->{'desc'})->[0];
+	    $desc =~ tr/\t\n/ /;	# remove tabs and newlines
+	}
+	
 	if (not defined $curr_tz) {
 	    # Assume that the first item in a listing doesn't need an
 	    # explicit timezone.
@@ -166,7 +174,7 @@ sub summarize( $$ ) {
 	    $channel = $_->{channel};
 	}
 
-	push @r, [ $start_hhmm, $stop_hhmm, $title, $sub_title, $channel ];
+	push @r, [ $start_hhmm, $stop_hhmm, $title, $sub_title, $channel, $desc ];
     }
     return @r;
 }
