@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_opt.pl,v 1.21 2012/02/11 19:33:36 rmeden Exp $
+# $Id: exe_opt.pl,v 1.28 2014/09/20 06:11:43 rmeden Exp $
 #
 # This is a simple script to generate options so PerlApp can make the EXE
 # it needs time values, so might as well put it in a perl script!
@@ -16,28 +16,29 @@ use File::Spec;
 #
 print '-nologo
 -force
--add="XMLTV::Ask::Term;XMLTV::Ask::Tk"
--add="XMLTV::ProgressBar::Term;XMLTV::ProgressBar::Tk;XMLTV::ProgressBar::None;"
--add="XMLTV::GUI"
--add="Class::MethodMaker::scalar"
--add "DateTime::Locale::en_US"
--add "DateTime::TimeZone::Europe::Copenhagen"
--add "DateTime::TimeZone::Europe::Helsinki"
--add "DateTime::TimeZone::Europe::Lisbon"
--add "DateTime::TimeZone::Asia::Jerusalem"
--add "DateTime::TimeZone::Asia::Kolkata"
--add="Tk::ProgressBar"
--trim="Net::FTP::A"
--trim="B"
--trim="Apache::Const;Apache::RequestIO;DIME::Payload;MIME::Entity;Apache::RequestRec;DIME::Message;I18N::Langinfo"
--trim="Apache2::RequestUtil;APR::Table;Apache2::Const;Apache2::RequestRec;Apache2::RequestIO"
--trim=DateTime::Format
+-add=XMLTV::
+-add=Date::Manip::
+-add DateTime::
+-add Params::Validate::**
+-add Date::Language::
+-bind=libexpat-1_.dll[file=C:\strawberry\c\bin\libexpat-1_.dll,extract]
+-bind=libxml2-2_.dll[file=C:\strawberry\c\bin\libxml2-2_.dll,extract]
+-bind=libiconv-2_.dll[file=C:\strawberry\c\bin\libiconv-2_.dll,extract]
+-bind=liblzma-5_.dll[file=C:\strawberry\c\bin\liblzma-5_.dll,extract]
+-bind=zlib1_.dll[file=C:\strawberry\c\bin\zlib1_.dll,extract]
+-trim=Class::MethodMaker::Scalar
+-trim=Class::MethodMaker::Engine
+-trim=JSON::PP58
+-trim=Test::Builder::IO::Scalar;
+-trim=Win32::Console
+-bind=libgcc_x86_470.dll[file=C:\strawberry\perl\bin\libgcc_x86_470.dll,extract]
 -info CompanyName="XMLTV Project http://www.xmltv.org"
 -info FileDescription="EXE bundle of XMLTV tools to manage TV Listings"
 -info InternalName=xmltv.exe
 -info OriginalFilename=xmltv.exe
 -info ProductName=xmltv
 -info LegalCopyright="GNU General Public License http://www.gnu.org/licenses/gpl.txt"
+-icon xmltv_logo.ico
 ';
 
 #
